@@ -10,9 +10,9 @@
 #define OP_MAPSTART OP_GREPSTART
 
 static PerlInterpreter *my_perl;
-extern char * name_load_me_2;
-extern unsigned long size_load_me_2;
-extern char load_me_2[];
+extern char * name_load_my_par_pl;
+extern unsigned long size_load_my_par_pl;
+extern char load_my_par_pl[];
 
 static char *stmpdir;
 static int options_count;
@@ -57,6 +57,7 @@ int main ( int argc, char **argv, char **env )
 {
     int exitstatus;
     int i;
+    int argno = 0;
 
 #ifdef PERL_GPROF_MONCONTROL
     PERL_GPROF_MONCONTROL(0);
@@ -112,14 +113,13 @@ int main ( int argc, char **argv, char **env )
 #endif /* ALLOW_PERL_OPTIONS */
     New(666, fakeargv, argc + EXTRA_OPTIONS + 1 + PROFILING_OPTION, char *);
 
-    int argno = 0;
     fakeargv[argno++] = argv[0];
 #ifdef PERL_PROFILING
     fakeargv[argno++] = "-d:DProf";
 #endif
 
     fakeargv[argno++] = "-e";
-    fakeargv[argno++] = load_me_2;
+    fakeargv[argno++] = load_my_par_pl;
 
 #ifndef ALLOW_PERL_OPTIONS
     fakeargv[argno++] = "--";
